@@ -3,9 +3,11 @@
 #' @author Ivan Jacob Agaloos Pesigan
 #'
 #' @param beta Numeric vector.
-#'   Regression slopes.
+#'   Partial regression slopes
+#'   \eqn{\boldsymbol{\beta}}.
 #' @param betastar Numeric vector.
-#'   Standardized regression slopes.
+#'   Standardized partial regression slopes
+#'   \eqn{\boldsymbol{\beta}^{\ast}}.
 #' @param p Positive integer.
 #'   `p` regressors.
 #' @param xnames Character vector.
@@ -27,19 +29,23 @@
     for (i in seq_len(p_dif)) {
       dif_betastar[i] <- betastar[dif_idx[1, i]] - betastar[dif_idx[2, i]]
       dif_beta[i] <- beta[dif_idx[1, i]] - beta[dif_idx[2, i]]
-      dif_names[i] <- paste0(xnames[dif_idx[1, i]], "-", xnames[dif_idx[2, i]])
+      dif_names[i] <- paste0(
+        xnames[dif_idx[1, i]],
+        "-",
+        xnames[dif_idx[2, i]]
+      )
     }
     names(dif_betastar) <- dif_names
     names(dif_beta) <- dif_names
   } else {
-    dif_betastar <- NULL
-    dif_beta <- NULL
-    dif_idx <- NULL
+    dif_betastar <- NA
+    dif_beta <- NA
+    dif_idx <- NA
   }
   return(
     list(
-      dif_betastar = dif_betastar,
       dif_beta = dif_beta,
+      dif_betastar = dif_betastar,
       dif_idx = dif_idx
     )
   )
